//[mahjong-utils](../../../index.md)/[mahjongutils](../index.md)/[CalcContext](index.md)

# CalcContext

[common]\
class [CalcContext](index.md)

## Constructors

| | |
|---|---|
| [CalcContext](-calc-context.md) | [common]<br>constructor() |

## Functions

| Name | Summary |
|---|---|
| [memo](memo.md) | [common]<br>inline fun &lt;[T](memo.md)&gt; [memo](memo.md)(key: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?, calc: () -&gt; [T](memo.md)): [T](memo.md) |
